@@ -41,9 +41,9 @@ class Blueprint(AbstractModel):
         :type BlueprintType: str
         :param ImageUrl: 镜像图片 URL。
         :type ImageUrl: str
-        :param RequiredSystemDiskSize: 镜像所需系统盘大小
+        :param RequiredSystemDiskSize: 镜像所需系统盘大小。
         :type RequiredSystemDiskSize: int
-        :param BlueprintState: 镜像状态，取值：ONLINE、OFFLINE
+        :param BlueprintState: 镜像状态。
         :type BlueprintState: str
         """
         self.BlueprintId = None
@@ -106,6 +106,15 @@ class Bundle(AbstractModel):
         :type InternetChargeType: str
         :param BundleSalesState: 套餐售卖状态,取值:‘AVAILABLE’(可用) , ‘SOLD_OUT’(售罄)
         :type BundleSalesState: str
+        :param BundleType: 套餐类型。
+取值范围：
+<li> GENERAL_BUNDLE：通用型</li><li> STORAGE_BUNDLE：存储型 </li>
+        :type BundleType: str
+        :param BundleDisplayLabel: 套餐展示标签.
+取值范围:
+"ACTIVITY": 活动套餐,
+"NORMAL": 普通套餐
+        :type BundleDisplayLabel: str
         """
         self.BundleId = None
         self.Memory = None
@@ -119,6 +128,8 @@ class Bundle(AbstractModel):
         self.InternetMaxBandwidthOut = None
         self.InternetChargeType = None
         self.BundleSalesState = None
+        self.BundleType = None
+        self.BundleDisplayLabel = None
 
 
     def _deserialize(self, params):
@@ -136,6 +147,8 @@ class Bundle(AbstractModel):
         self.InternetMaxBandwidthOut = params.get("InternetMaxBandwidthOut")
         self.InternetChargeType = params.get("InternetChargeType")
         self.BundleSalesState = params.get("BundleSalesState")
+        self.BundleType = params.get("BundleType")
+        self.BundleDisplayLabel = params.get("BundleDisplayLabel")
 
 
 class CreateFirewallRulesRequest(AbstractModel):
@@ -314,7 +327,7 @@ class DescribeBundlesRequest(AbstractModel):
         :param Limit: 返回数量，默认为 20，最大值为 100。关于`Limit`的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/product/1207/47578)中的相关小节。
         :type Limit: int
         :param Filters: 过滤器列表。
-<li>bundle-id</li>按照【镜像 ID】进行过滤。
+<li>bundle-id</li>按照【套餐 ID】进行过滤。
 类型：String
 必选：否
 <li>support-platform-type</li>按照【系统类型】进行过滤。
@@ -1058,7 +1071,7 @@ class TrafficPackage(AbstractModel):
         """
         :param TrafficPackageId: 流量包ID。
         :type TrafficPackageId: str
-        :param TrafficUsed: 流量包生效周期内的总流量，单位字节。
+        :param TrafficUsed: 流量包生效周期内已使用流量，单位字节。
         :type TrafficUsed: int
         :param TrafficPackageTotal: 流量包生效周期内的总流量，单位字节。
         :type TrafficPackageTotal: int
